#!/bin/sh

# $1 parameter should be one of 'stable'(default), 'devel' or 'candidate'

# Expecting file ./packages containing one required package on every line:
# condor
# condor-test

RHVERSION=$(rpm -q --qf "%{version}" redhat-release 2>/dev/null | cut -b1)
repo=mrg-rhel$RHVERSION-${1:-devel}
basename=${0##*/}
tmpdir=`mktemp -d /tmp/$basename.XX`
p2install=$tmpdir/install


condorclean () {
	service condor stop
	rm -rf /var/lib/condor/spool/*
}

cleanup () {
	rm -rf $tmpdir
	userdel -r test1
	condorclean
	killall perl
	exit
} > /dev/null 2>&1

check () {
	while read package
	do
		rpm -q $package || echo $package > $p2install
	done < packages
	test ! -r $p2install ||
		cat $p2install | xargs yum -y --enablerepo=$repo install
}

settle () {
        printf "Waiting for Condor slots to show up: "
        while
                ! condor_status -any | grep -q Machine
        do
                printf "."
                sleep 1
        done
        printf " ready\n"
}

###########################################
# Here the important last page follows
###########################################

trap cleanup EXIT
check || exit 1

condorclean
service condor start
settle

useradd test1
chown -R test1 $tmpdir

su test1 -c "
	cp -rL /usr/libexec/condor/test $tmpdir/
	cd $tmpdir/test/condor_tests
	$PWD/add_dag_args.pl
	cp -rL /usr/libexec/condor/test $tmpdir/test2
	cd $tmpdir/test2/condor_tests
	./batch_test.pl -d . -f list_dagman
"
